from zope.interface import Interface

class IRichFileImageLayer(Interface):
    """ Marker interface that defines a Zope 3 browser layer.
    """

class IRichFileImageSite(Interface):
    """ Marker interface for sites with this product installed.
    """ 

class IImage(Interface):
    """
    """
    
class IImageable(Interface):
    """
    """
